Snippet dependencies
=====================

.. automodule:: drain_swamp.snippet_dependencies
   :members:
   :undoc-members:
   :platform: Unix
   :synopsis: pyproject.toml snippet dealing with dependencies
